@@ -5,7 +5,7 @@
         Copyright 2001 Otto Bruggeman <otto.bruggeman@home.nl>
         Copyright 2001 John Firebaugh <jfirebaugh@kde.org>
 ****************************************************************************/
- 
+
 /***************************************************************************
 **
 **   This program is free software; you can redistribute it and/or modify
@@ -18,9 +18,8 @@
 #ifndef SETTINGSBASE_H
 #define SETTINGSBASE_H
 
-#include <QtCore/QObject>
+#include <QObject>
 
-#include "kompare.h"
 #include "diff2_export.h"
 
 class QWidget;
@@ -28,14 +27,14 @@ class KConfig;
 
 class DIFF2_EXPORT SettingsBase : public QObject
 {
-Q_OBJECT
+    Q_OBJECT
 public:
-	SettingsBase( QWidget* parent );
-	~SettingsBase();
+    explicit SettingsBase(QWidget* parent);
+    ~SettingsBase() override;
 
 public:
-	virtual void loadSettings( KConfig* config );
-	virtual void saveSettings( KConfig* config );
+    virtual void loadSettings(KConfig* config);
+    virtual void saveSettings(KConfig* config);
 };
 
 #endif
